//---------------------------------------------------------------------------//
// $Id: x19.java 6653 2006-05-31 09:09:08Z andrewross $
//---------------------------------------------------------------------------//

//---------------------------------------------------------------------------//
// Copyright (C) 2001  Geoffrey Furnish
//
// This file is part of PLplot.
//
// PLplot is free software; you can redistribute it and/or modify
// it under the terms of the GNU Library General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// PLplot is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public License
// along with PLplot; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
//---------------------------------------------------------------------------//

//---------------------------------------------------------------------------//
// Implementation of PLplot example 19 in Java.
//---------------------------------------------------------------------------//

package plplot.examples;

class x19 {

    public static void main( String[] args ) 
    {
        System.out.println( "x19 not implemented yet." );
    }
}

//---------------------------------------------------------------------------//
//                              End of x19.java
//---------------------------------------------------------------------------//
